Documentation
¶
Index ¶
- Variables
- type EnrichedUser
- func (*EnrichedUser) Descriptor() ([]byte, []int)
- func (x *EnrichedUser) GetEmail() string
- func (x *EnrichedUser) GetId() string
- func (x *EnrichedUser) GetName() string
- func (x *EnrichedUser) GetProfile() *Profile
- func (*EnrichedUser) ProtoMessage()
- func (x *EnrichedUser) ProtoReflect() protoreflect.Message
- func (x *EnrichedUser) Reset()
- func (x *EnrichedUser) String() string
- type GetProfileRequest
- type GetProfileResponse
- func (*GetProfileResponse) Descriptor() ([]byte, []int)
- func (x *GetProfileResponse) GetError() string
- func (x *GetProfileResponse) GetProfile() *Profile
- func (*GetProfileResponse) ProtoMessage()
- func (x *GetProfileResponse) ProtoReflect() protoreflect.Message
- func (x *GetProfileResponse) Reset()
- func (x *GetProfileResponse) String() string
- type GetUserRequest
- type GetUserResponse
- func (*GetUserResponse) Descriptor() ([]byte, []int)
- func (x *GetUserResponse) GetError() string
- func (x *GetUserResponse) GetUser() *EnrichedUser
- func (*GetUserResponse) ProtoMessage()
- func (x *GetUserResponse) ProtoReflect() protoreflect.Message
- func (x *GetUserResponse) Reset()
- func (x *GetUserResponse) String() string
- type ListProfilesRequest
- type ListProfilesResponse
- func (*ListProfilesResponse) Descriptor() ([]byte, []int)
- func (x *ListProfilesResponse) GetProfiles() []*Profile
- func (*ListProfilesResponse) ProtoMessage()
- func (x *ListProfilesResponse) ProtoReflect() protoreflect.Message
- func (x *ListProfilesResponse) Reset()
- func (x *ListProfilesResponse) String() string
- type ListUsersRequest
- type ListUsersResponse
- type Profile
- func (*Profile) Descriptor() ([]byte, []int)
- func (x *Profile) GetAvatar() string
- func (x *Profile) GetBio() string
- func (x *Profile) GetLocation() string
- func (x *Profile) GetUserId() string
- func (x *Profile) GetVerified() bool
- func (x *Profile) GetWebsite() string
- func (*Profile) ProtoMessage()
- func (x *Profile) ProtoReflect() protoreflect.Message
- func (x *Profile) Reset()
- func (x *Profile) String() string
- type User
- type UserEvent
- func (*UserEvent) Descriptor() ([]byte, []int)
- func (x *UserEvent) GetEventType() string
- func (x *UserEvent) GetTimestamp() int64
- func (x *UserEvent) GetUserId() string
- func (*UserEvent) ProtoMessage()
- func (x *UserEvent) ProtoReflect() protoreflect.Message
- func (x *UserEvent) Reset()
- func (x *UserEvent) String() string
Constants ¶
This section is empty.
Variables ¶
var File_proto_services_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type EnrichedUser ¶
type EnrichedUser struct {
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
Name string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
Email string `protobuf:"bytes,3,opt,name=email,proto3" json:"email,omitempty"`
Profile *Profile `protobuf:"bytes,4,opt,name=profile,proto3" json:"profile,omitempty"`
// contains filtered or unexported fields
}
EnrichedUser combines user data with profile data.
func (*EnrichedUser) Descriptor ¶
func (*EnrichedUser) Descriptor() ([]byte, []int)
func (*EnrichedUser) GetEmail ¶
func (x *EnrichedUser) GetEmail() string
func (*EnrichedUser) GetId ¶
func (x *EnrichedUser) GetId() string
func (*EnrichedUser) GetName ¶
func (x *EnrichedUser) GetName() string
func (*EnrichedUser) GetProfile ¶
func (x *EnrichedUser) GetProfile() *Profile
func (*EnrichedUser) ProtoMessage ¶
func (*EnrichedUser) ProtoMessage()
func (*EnrichedUser) ProtoReflect ¶
func (x *EnrichedUser) ProtoReflect() protoreflect.Message
func (*EnrichedUser) Reset ¶
func (x *EnrichedUser) Reset()
func (*EnrichedUser) String ¶
func (x *EnrichedUser) String() string
type GetProfileRequest ¶
type GetProfileRequest struct {
UserId string `protobuf:"bytes,1,opt,name=user_id,json=userId,proto3" json:"user_id,omitempty"`
// contains filtered or unexported fields
}
GetProfileRequest is the request to get a profile by user ID.
func (*GetProfileRequest) Descriptor ¶
func (*GetProfileRequest) Descriptor() ([]byte, []int)
func (*GetProfileRequest) GetUserId ¶
func (x *GetProfileRequest) GetUserId() string
func (*GetProfileRequest) ProtoMessage ¶
func (*GetProfileRequest) ProtoMessage()
func (*GetProfileRequest) ProtoReflect ¶
func (x *GetProfileRequest) ProtoReflect() protoreflect.Message
func (*GetProfileRequest) Reset ¶
func (x *GetProfileRequest) Reset()
func (*GetProfileRequest) String ¶
func (x *GetProfileRequest) String() string
type GetProfileResponse ¶
type GetProfileResponse struct {
Profile *Profile `protobuf:"bytes,1,opt,name=profile,proto3" json:"profile,omitempty"`
Error string `protobuf:"bytes,2,opt,name=error,proto3" json:"error,omitempty"`
// contains filtered or unexported fields
}
GetProfileResponse is the response containing a profile.
func (*GetProfileResponse) Descriptor ¶
func (*GetProfileResponse) Descriptor() ([]byte, []int)
func (*GetProfileResponse) GetError ¶
func (x *GetProfileResponse) GetError() string
func (*GetProfileResponse) GetProfile ¶
func (x *GetProfileResponse) GetProfile() *Profile
func (*GetProfileResponse) ProtoMessage ¶
func (*GetProfileResponse) ProtoMessage()
func (*GetProfileResponse) ProtoReflect ¶
func (x *GetProfileResponse) ProtoReflect() protoreflect.Message
func (*GetProfileResponse) Reset ¶
func (x *GetProfileResponse) Reset()
func (*GetProfileResponse) String ¶
func (x *GetProfileResponse) String() string
type GetUserRequest ¶
type GetUserRequest struct {
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
// contains filtered or unexported fields
}
GetUserRequest is the request to get a user by ID.
func (*GetUserRequest) Descriptor ¶
func (*GetUserRequest) Descriptor() ([]byte, []int)
func (*GetUserRequest) GetId ¶
func (x *GetUserRequest) GetId() string
func (*GetUserRequest) ProtoMessage ¶
func (*GetUserRequest) ProtoMessage()
func (*GetUserRequest) ProtoReflect ¶
func (x *GetUserRequest) ProtoReflect() protoreflect.Message
func (*GetUserRequest) Reset ¶
func (x *GetUserRequest) Reset()
func (*GetUserRequest) String ¶
func (x *GetUserRequest) String() string
type GetUserResponse ¶
type GetUserResponse struct {
User *EnrichedUser `protobuf:"bytes,1,opt,name=user,proto3" json:"user,omitempty"`
Error string `protobuf:"bytes,2,opt,name=error,proto3" json:"error,omitempty"`
// contains filtered or unexported fields
}
GetUserResponse is the response containing a user.
func (*GetUserResponse) Descriptor ¶
func (*GetUserResponse) Descriptor() ([]byte, []int)
func (*GetUserResponse) GetError ¶
func (x *GetUserResponse) GetError() string
func (*GetUserResponse) GetUser ¶
func (x *GetUserResponse) GetUser() *EnrichedUser
func (*GetUserResponse) ProtoMessage ¶
func (*GetUserResponse) ProtoMessage()
func (*GetUserResponse) ProtoReflect ¶
func (x *GetUserResponse) ProtoReflect() protoreflect.Message
func (*GetUserResponse) Reset ¶
func (x *GetUserResponse) Reset()
func (*GetUserResponse) String ¶
func (x *GetUserResponse) String() string
type ListProfilesRequest ¶
type ListProfilesRequest struct {
// contains filtered or unexported fields
}
ListProfilesRequest is the request to list all profiles.
func (*ListProfilesRequest) Descriptor ¶
func (*ListProfilesRequest) Descriptor() ([]byte, []int)
func (*ListProfilesRequest) ProtoMessage ¶
func (*ListProfilesRequest) ProtoMessage()
func (*ListProfilesRequest) ProtoReflect ¶
func (x *ListProfilesRequest) ProtoReflect() protoreflect.Message
func (*ListProfilesRequest) Reset ¶
func (x *ListProfilesRequest) Reset()
func (*ListProfilesRequest) String ¶
func (x *ListProfilesRequest) String() string
type ListProfilesResponse ¶
type ListProfilesResponse struct {
Profiles []*Profile `protobuf:"bytes,1,rep,name=profiles,proto3" json:"profiles,omitempty"`
// contains filtered or unexported fields
}
ListProfilesResponse is the response containing all profiles.
func (*ListProfilesResponse) Descriptor ¶
func (*ListProfilesResponse) Descriptor() ([]byte, []int)
func (*ListProfilesResponse) GetProfiles ¶
func (x *ListProfilesResponse) GetProfiles() []*Profile
func (*ListProfilesResponse) ProtoMessage ¶
func (*ListProfilesResponse) ProtoMessage()
func (*ListProfilesResponse) ProtoReflect ¶
func (x *ListProfilesResponse) ProtoReflect() protoreflect.Message
func (*ListProfilesResponse) Reset ¶
func (x *ListProfilesResponse) Reset()
func (*ListProfilesResponse) String ¶
func (x *ListProfilesResponse) String() string
type ListUsersRequest ¶
type ListUsersRequest struct {
// contains filtered or unexported fields
}
ListUsersRequest is the request to list all users.
func (*ListUsersRequest) Descriptor ¶
func (*ListUsersRequest) Descriptor() ([]byte, []int)
func (*ListUsersRequest) ProtoMessage ¶
func (*ListUsersRequest) ProtoMessage()
func (*ListUsersRequest) ProtoReflect ¶
func (x *ListUsersRequest) ProtoReflect() protoreflect.Message
func (*ListUsersRequest) Reset ¶
func (x *ListUsersRequest) Reset()
func (*ListUsersRequest) String ¶
func (x *ListUsersRequest) String() string
type ListUsersResponse ¶
type ListUsersResponse struct {
Users []*EnrichedUser `protobuf:"bytes,1,rep,name=users,proto3" json:"users,omitempty"`
// contains filtered or unexported fields
}
ListUsersResponse is the response containing all users.
func (*ListUsersResponse) Descriptor ¶
func (*ListUsersResponse) Descriptor() ([]byte, []int)
func (*ListUsersResponse) GetUsers ¶
func (x *ListUsersResponse) GetUsers() []*EnrichedUser
func (*ListUsersResponse) ProtoMessage ¶
func (*ListUsersResponse) ProtoMessage()
func (*ListUsersResponse) ProtoReflect ¶
func (x *ListUsersResponse) ProtoReflect() protoreflect.Message
func (*ListUsersResponse) Reset ¶
func (x *ListUsersResponse) Reset()
func (*ListUsersResponse) String ¶
func (x *ListUsersResponse) String() string
type Profile ¶
type Profile struct {
UserId string `protobuf:"bytes,1,opt,name=user_id,json=userId,proto3" json:"user_id,omitempty"`
Bio string `protobuf:"bytes,2,opt,name=bio,proto3" json:"bio,omitempty"`
Avatar string `protobuf:"bytes,3,opt,name=avatar,proto3" json:"avatar,omitempty"`
Location string `protobuf:"bytes,4,opt,name=location,proto3" json:"location,omitempty"`
Website string `protobuf:"bytes,5,opt,name=website,proto3" json:"website,omitempty"`
Verified bool `protobuf:"varint,6,opt,name=verified,proto3" json:"verified,omitempty"`
// contains filtered or unexported fields
}
Profile represents a user's profile information.
func (*Profile) Descriptor ¶
func (*Profile) GetLocation ¶
func (*Profile) GetVerified ¶
func (*Profile) GetWebsite ¶
func (*Profile) ProtoMessage ¶
func (*Profile) ProtoMessage()
func (*Profile) ProtoReflect ¶
func (x *Profile) ProtoReflect() protoreflect.Message
type User ¶
type User struct {
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
Name string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
Email string `protobuf:"bytes,3,opt,name=email,proto3" json:"email,omitempty"`
// contains filtered or unexported fields
}
User represents a user in the system.
func (*User) Descriptor ¶
func (*User) ProtoMessage ¶
func (*User) ProtoMessage()
func (*User) ProtoReflect ¶
func (x *User) ProtoReflect() protoreflect.Message
type UserEvent ¶
type UserEvent struct {
EventType string `protobuf:"bytes,1,opt,name=event_type,json=eventType,proto3" json:"event_type,omitempty"`
UserId string `protobuf:"bytes,2,opt,name=user_id,json=userId,proto3" json:"user_id,omitempty"`
Timestamp int64 `protobuf:"varint,3,opt,name=timestamp,proto3" json:"timestamp,omitempty"`
// contains filtered or unexported fields
}
UserEvent represents an event related to user activity.
func (*UserEvent) Descriptor ¶
func (*UserEvent) GetEventType ¶
func (*UserEvent) GetTimestamp ¶
func (*UserEvent) ProtoMessage ¶
func (*UserEvent) ProtoMessage()
func (*UserEvent) ProtoReflect ¶
func (x *UserEvent) ProtoReflect() protoreflect.Message
Click to show internal directories.
Click to hide internal directories.